Fitting Schemes
================

.. autoclass:: clease.regression.LinearRegression
    :members:

.. autoclass:: clease.regression.Tikhonov
    :members:

.. autoclass:: clease.regression.Lasso
    :members:

.. autoclass:: clease.regression.ga_fit.GAFit
    :members:

.. autoclass:: clease.regression.bayesian_compressive_sensing.BayesianCompressiveSensing
    :members:

.. autoclass:: clease.regression.sequential_cluster_ridge.SequentialClusterRidge
    :members:
